# Example Package

### This is a python package that can be utilised to ingest receipt/invoice/orders data from the user's gmail. Developer's have to import the package and pass the access token to the required function and you can fetch the data from user's gmail. There is a feature utilising LLM's to structure the data into a json object , many such cool features are on the way . 
